/*
 * Copyright 2022 James Bowring, Noah McLean, Scott Burdick, and CIRDLES.org.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

plugins {
    java
    `maven-publish`
}


java {
    sourceCompatibility = JavaVersion.VERSION_17
    targetCompatibility = JavaVersion.VERSION_17
}

repositories {
    mavenCentral()

    maven { url = uri("https://jitpack.io") }

    maven { url = uri("https://plugins.gradle.org/m2/") }

    flatDir { dirs("libs") }
}


dependencies {
    // https://mvnrepository.com/artifact/org.jetbrains/annotations
    implementation("org.jetbrains:annotations:23.0.0") //group: 'org.jetbrains', name: 'annotations', version: '23.0.0'

}


val mavenArtifactId = name
val mavenGroupId = "org.cirdles"
val mavenVersion = "0.0.3"


object Versions {
    const val junitVersion = "5.8.2"
    // Creates desired junit version that can be called in all subprojects
}

group = mavenGroupId
version = mavenVersion



tasks {

    compileJava {
        options.encoding = "UTF-8"
    }

    compileTestJava {
        options.encoding = "UTF-8"
    }


    val packageJavadoc by creating(Jar::class) {
        from(javadoc)
        archiveClassifier.set("javadoc")
        dependsOn(javadoc)
        // currently not called unless uncommented in artifacts
    }

    val sourcesJar by creating(Jar::class) {
        duplicatesStrategy = DuplicatesStrategy.INCLUDE
        dependsOn(classes)
        archiveClassifier.set("sources")
        from(sourceSets["main"].allSource)
    }


    artifacts {
        archives(jar)
        archives(sourcesJar)
        //  Uncomment next line to produce javadocs
        //archives(packageJavadoc)
    }

}

tasks.withType(JavaCompile::class) {

    options.compilerArgs.add("-Xlint:deprecation")
    options.compilerArgs.add("-Xlint:unchecked")
    options.encoding = "UTF-8"
    println("Compiler args: " + options.compilerArgs)

}

tasks.withType<Javadoc> {
    (options as StandardJavadocDocletOptions).addStringOption("Xdoclint:none", "-quiet")
}

tasks.withType(JavaCompile::class) {
    options.encoding = "UTF-8"
}

tasks.register("CreateFolder") {
    doLast {
        sourceSets["main"].allSource.srcDirs.forEach { srcDir: File ->
            if (!srcDir.isDirectory()) {
                println("Create source folder: $srcDir")
                srcDir.mkdirs()
            }
        }
    }
}



publishing {
    publications {
        create<MavenPublication>("mavenJava") {
            from(components["java"])
            artifactId = mavenArtifactId

            pom {
                licenses {
                    license {
                        name.set("The Apache License, Version 2.0")
                        url.set("http://www.apache.org/licenses/LICENSE-2.0.txt")
                    }
                }
            }
        }
    }
}